/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2008-2009 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __PACKAGEKIT_PRIVATE_H__
#define __PACKAGEKIT_PRIVATE_H__

#define __PACKAGEKIT_H_INSIDE__

#include <packagekit-glib2/pk-task-sync.h>
#include <packagekit-glib2/pk-task-text.h>
#include <packagekit-glib2/pk-console-private.h>
#include <packagekit-glib2/pk-progress-bar.h>
#include <packagekit-glib2/pk-spawn-polkit-agent.h>

#undef __PACKAGEKIT_H_INSIDE__

#endif /* __PACKAGEKIT_PRIVATE_H__ */

